/* neighboring8.h
 */
#ifndef OSL_NEIGHBORING8_H
#define OSL_NEIGHBORING8_H

#include "osl/boardTable.h"

namespace osl
{
  struct Neighboring8
  {
    static bool isNeighboring8(Square from,Square to)
    {
      return (from != to)
	&& (to == from+Board_Table.getShortOffsetNotKnight(Offset32(to,from)));
    }
  };

} // namespace osl

#endif /* OSL_NEIGHBORING8_H */
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
